require 'feedjira'

module SpotTracks
  class Feed
    attr_reader :username

    HOST = 'http://ws.audioscrobbler.com'

    def initialize(username)
      @username = username
    end

    def title
      return unless valid?
      client.title
    end

    def url
      return unless valid?
      client.url
    end

    def tracks
      return [] unless valid?
      client.entries.map do |entry|
        SpotTracks::Track.search entry.title
      end.compact
    end

    def valid?
      !!client
    end

    def to_json
      {
        title: title,
        url: url,
        tracks: tracks.map(&:to_h)
      }.to_json
    end

    private

    def client
      @client ||= begin
        feed = Feedjira::Feed.fetch_and_parse(rss_url)
        feed.is_a?(Feedjira::Parser::RSS) ? feed : nil
      end
    end

    def rss_url
      "#{HOST}/1.0/user/#{username}/recenttracks.rss"
    end
  end
end
