module SpotTracks
  class Track
    attr_reader :name, :artist, :image, :uri

    def initialize(params = {})
      @name = params[:name]
      @artist = params[:artist]
      @image = params[:image]
      @uri = params[:uri]
    end

    def self.search(title)
      SpotTracks::Player.new.search(title)
    end

    def self.parse(data = {})
      tracks = data.fetch('tracks', {})
      item   = tracks.fetch('items', []).first
      return if item.nil?

      album  = item['album']
      artist = item['artists'].first
      image  = album['images'].detect{|i| i['height'] == 300 }

      new({
        name:   item['name'],
        artist: artist['name'],
        image:  image['url'],
        uri:    item['uri']
      })
    end

    def title
      "#{artist} - #{name}"
    end

    def to_h
      {
        title: title, name: name, artist: artist,
        urls: { image: image, uri: uri }
      }
    end
  end
end
